@@ -23,7 +23,6 @@
 #include <KFileUtils>
 #include <KPluginMetaData>
 #include <KSharedConfig>
-#include <memory>
 
 #include "abstractrunner_p.h"
 #include "dbusrunner_p.h"
@@ -667,7 +666,7 @@ QString RunnerManager::getHistorySuggestion(const QString &typedQuery) const
             return entry;
         }
     }
-    return QString();
+    return {};
 }
 
 void RunnerManager::reset()
